﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Xml.Linq;
using DocumentFormat.OpenXml.Packaging;
using OpenXmlPowerTools;

class TestTocAdder
{
    static void Main(string[] args)
    {
        DirectoryInfo di = new DirectoryInfo(".");
        foreach (var file in di.GetFiles("*.docx"))
            file.Delete();
        DirectoryInfo di2 = new DirectoryInfo("../../../");
        foreach (var file in di2.GetFiles("*.docx"))
            file.CopyTo(di.FullName + "/" + file.Name);

        List<string> filesToProcess = new List<string>();

        // Inserts a basic TOC before the first paragraph of the document
        using (WordprocessingDocument wdoc =
            WordprocessingDocument.Open("Test01.docx", true))
        {
            XElement firstPara = wdoc
                .MainDocumentPart
                .GetXDocument()
                .Descendants(W.p)
                .FirstOrDefault();
            TocAdder.AddToc(wdoc, firstPara,
                @"TOC \o '1-3' \h \z \u", null, null);
        }

        // Inserts a TOC after the title of the document
        using (WordprocessingDocument wdoc =
            WordprocessingDocument.Open("Test02.docx", true))
        {
            XElement secondPara = wdoc
                .MainDocumentPart
                .GetXDocument()
                .Descendants(W.p)
                .Skip(1)
                .FirstOrDefault();
            TocAdder.AddToc(wdoc, secondPara,
                @"TOC \o '1-3' \h \z \u", null, null);
        }

        // Inserts a TOC with a different title
        using (WordprocessingDocument wdoc =
            WordprocessingDocument.Open("Test03.docx", true))
        {
            XElement firstPara = wdoc
                .MainDocumentPart
                .GetXDocument()
                .Descendants(W.p)
                .FirstOrDefault();
            TocAdder.AddToc(wdoc, firstPara,
                @"TOC \o '1-3' \h \z \u", "Table of Contents", null);
        }

        // Inserts a TOC that includes headings through level 4
        using (WordprocessingDocument wdoc =
            WordprocessingDocument.Open("Test04.docx", true))
        {
            XElement firstPara = wdoc
                .MainDocumentPart
                .GetXDocument()
                .Descendants(W.p)
                .FirstOrDefault();
            TocAdder.AddToc(wdoc, firstPara,
                @"TOC \o '1-4' \h \z \u", null, null);
        }

        // Inserts a table of figures
        using (WordprocessingDocument wdoc =
            WordprocessingDocument.Open("Test05.docx", true))
        {
            XElement firstPara = wdoc
                .MainDocumentPart
                .GetXDocument()
                .Descendants(W.p)
                .Skip(1)
                .FirstOrDefault();
            TocAdder.AddTof(wdoc, firstPara,
                @"TOC \h \z \c ""Figure""", null);
        }
    }
}
